## Dash Labs tech preview
This repository contains a work-in-progress technical preview of potential future Dash features.

## Documentation
The documentation for Dash Labs can be found in the [docs/](./docs/) directory.
  - [01-Overview.md](https://github.com/plotly/dash-labs/blob/main/docs/01-Overview.md)
  - [02-CallbackEnhancements.md](https://github.com/plotly/dash-labs/blob/main/docs/02-CallbackEnhancements.md)
  - [03-TemplateLayoutSystem.md](https://github.com/plotly/dash-labs/blob/main/docs/03-TemplateLayoutSystem.md)
  - [04-PredefinedTemplates.md](https://github.com/plotly/dash-labs/blob/main/docs/04-PredefinedTemplates.md)
  - [05-ComponentPlugingPattern.md](https://github.com/plotly/dash-labs/blob/main/docs/05-ComponentPlugingPattern.md)

Various demos are located in the [docs/demos](./docs/demos) directory.

## Installation
To install the tech preview, first clone this repository

```
$ pip dash-labs
```

To use the templates based on `dash-bootstrap-components`, a few additional packages are required:

```
$ pip dash-bootstrap-components spectra colormath 
```
